@@ -185,4 +185,13 @@ namespace snmalloc
 
     return ((alignment - 1) | (size - 1)) + 1;
   }
+
+  SNMALLOC_FAST_PATH static size_t round_size(size_t size)
+  {
+    if (size > size_to_sizeclass(NUM_SIZECLASSES - 1))
+    {
+      return bits::next_pow2(size);
+    }
+    return sizeclass_to_size(size_to_sizeclass(size));
+  }
 } // namespace snmalloc
