@@ -35,6 +35,11 @@ extern "C"
     ThreadAlloc::get_noncachable()->dealloc(ptr);
   }
 
+  SNMALLOC_EXPORT void SNMALLOC_NAME_MANGLE(cfree)(void* ptr)
+  {
+    SNMALLOC_NAME_MANGLE(free)(ptr);
+  }
+
   SNMALLOC_EXPORT void* SNMALLOC_NAME_MANGLE(calloc)(size_t nmemb, size_t size)
   {
     bool overflow = false;
@@ -81,7 +86,7 @@ extern "C"
 #endif
     size_t sz = Alloc::alloc_size(ptr);
     // Keep the current allocation if the given size is in the same sizeclass.
-    if (sz == sizeclass_to_size(size_to_sizeclass(size)))
+    if (sz == round_size(size))
       return ptr;
 
     void* p = SNMALLOC_NAME_MANGLE(malloc)(size);
