@@ -37,11 +37,15 @@ namespace snmalloc
     template<bool page_aligned = false>
     void zero(void* p, size_t size) noexcept
     {
-// QEMU does not seem to be giving the desired behaviour for MADV_DONTNEED.
-// switch back to memset only for QEMU.
+      // QEMU does not seem to be giving the desired behaviour for
+      // MADV_DONTNEED. switch back to memset only for QEMU.
 #  ifndef SNMALLOC_QEMU_WORKAROUND
-      if (page_aligned || is_aligned_block<OS_PAGE_SIZE>(p, size))
+      if (
+        (page_aligned || is_aligned_block<OS_PAGE_SIZE>(p, size)) &&
+        (size > SLAB_SIZE))
       {
+        // Only use this on large allocations as memset faster, and doesn't
+        // introduce IPI so faster for small allocations.
         SNMALLOC_ASSERT(is_aligned_block<OS_PAGE_SIZE>(p, size));
         madvise(p, size, MADV_DONTNEED);
       }
